%% Plot Fig 3D

if ~exist('Fig3DFplot', 'dir')
   mkdir Fig3DFplot
end

cmapRY = [linspace(1,1,256)',linspace(0.3,1,256)',linspace(0.3,0,256)'];%red
cmapGY =[linspace(0.2,1,256)',linspace(0.8,1,256)',linspace(0.2,0,256)'];%green
cmapBY = [linspace(0.3,1,256)',linspace(0.3,1,256)',linspace(1,0,256)'];  %blue
grayred = [linspace(0.5,1,256); linspace(0.5,0.3,256); linspace(0.5,0.3,256)]';
graygreen = [linspace(0.5,0.2,256); linspace(0.5,0.8,256); linspace(0.5,0.2,256)]';
whitered = [linspace(1,1,256); linspace(1,0.3,256); linspace(1,0.3,256)]';
whitegreen = [linspace(1,0.2,256); linspace(1,0.8,256); linspace(1,0.2,256)]';
cmapA = whitered;
%%
D_lst = 3.6*[10^-1, 10^0, 10^1, 10^2];
gausWinSize = round(5*logspace(0,1,4));

figure;

for cont = 1:4
    filename = sprintf('Fig3DFdata/Fig3DF_Dr%08.2f_t200_reflective_LA_TI0Pos1_20x1000.mat',D_lst(cont));
    res = load(filename);
    Za = res.results.Za;
    ZaEnd = res.results.Za(:,:,end);
    Aend = mean(ZaEnd, 1);
    ZaW = mean(Za,1);

    kymoAll = squeeze(ZaW)';
    kymoT40 = kymoAll(1:40,1:400);
    subplot(4,1,cont)
    imagesc(kymoT40);
    colormap(cmapA);
    colorbar;
    caxis([0, 50]);
    xlabel('cell position in X-axis')
    ylabel('t (h)')
    
    A_totalcorr = xcorr(Aend','coeff');
    A_corr = A_totalcorr((size(A_totalcorr,1)+1)/2:end);
    w = gausswin(gausWinSize(cont));
    A_fltr = filter(w,1,A_corr);
    [Acorr_maxima,Acorr_maxIdx] = findpeaks(A_fltr);
    maxID = [Acorr_maxima,Acorr_maxIdx];
    if size(maxID,1)>6
        maxID = maxID(1:6,:);
    end
    wlgth(cont) = (maxID(end,2) - maxID(1,2))/(size(maxID,1)-1);
    
    titlename = sprintf('D = %.2f wavelength = %.2f',D_lst(cont),wlgth(cont));
    title(titlename);

end

figname = sprintf('Fig3DFplot/Fig3D');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));

%%
figure;
x = sqrt(D_lst);
y = wlgth;
% b = regress(y, x); 
P = polyfit(x,y,1);
yfit = P(1)*x+P(2);
b = y/x;
hold on;
plot(x,y,'o')
plot(x,b*x,'g-.');
plot(x,yfit,'r-.');
set(gca,'xscale','log');
set(gca,'yscale','log');
xlabel('sqrt(D)');
ylabel('\lambda');
xlim([0.2,70]);
% grid on;
box on;

figname = sprintf('Fig3DFplot/Fig3D_LambdavsD');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));


%%
% D_lst = 3.6*[10^-1, 10^0, 10^1, 10^2];
% gausWinSize = round(5*logspace(0,1,4));
skipcont = [0,1,2,2];

for cont = 1:4
    filename = sprintf('Fig3DFdata/Fig3DF_Dr%08.2f_t200_reflective_LA_TI0Pos1_20x1000.mat',D_lst(cont));
    res = load(filename);
    Za = res.results.Za;
    Akymo = squeeze(mean(Za,1));
    ZaEnd = res.results.Za(:,:,end);
    Aend = mean(ZaEnd, 1);
    [Acorr_maxima,Acorr_maxIdx] = findpeaks(Aend);
    maxID = Acorr_maxIdx(1:skipcont(cont)+1:end);
    maxID_lst(cont,:) = maxID(1:4);

    for id = 1:4
        tr = Akymo(maxID(id),:);
        arsPoint = find(tr>1.2*tr(1));
        arsPointCont(cont, id) = arsPoint(1);
    end
end
meanT = (arsPointCont(:,3) + arsPointCont(:,4) - arsPointCont(:,1) - arsPointCont(:,2))/4;
velosity = wlgth./meanT';
%%
figure;
plot(x,velosity,'o');
set(gca,'xscale','log');
set(gca,'yscale','log');
xlabel('sqrt(D)');
ylabel('v');
xlim([0.2, 70]);
ylim([0.1, 100]);
box on;

figname = sprintf('Fig3DFplot/Fig3D_VvsD');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));

figure;
plot(x,meanT','o');
set(gca,'xscale','log');
set(gca,'yscale','log');
xlabel('sqrt(D)');
ylabel('T');
xlim([0.2, 70]);
ylim([0.1, 100]);
box on;

figname = sprintf('Fig3DFplot/Fig3D_TvsD');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));

