%% Model parameters

if ~exist('Fig3DFplot', 'dir')
   mkdir Fig3DFplot
end

paramsModel.para = [100, 80, 1.5, 0.5, 10, 10, 10, 2, 0, 3.6];
paramsModel.a_A = paramsModel.para(1);
paramsModel.a_R = paramsModel.para(2);
paramsModel.g_A = paramsModel.para(3); 
paramsModel.g_R = paramsModel.para(4);
paramsModel.K_A = paramsModel.para(5);
paramsModel.K_R = paramsModel.para(6);
paramsModel.K = paramsModel.para(7);
paramsModel.H = paramsModel.para(8);
paramsModel.Da = paramsModel.para(9);
paramsModel.Dr = paramsModel.para(10);

w = 1000;

a_A = paramsModel.para(1);
a_R = paramsModel.para(2);
g_A = paramsModel.para(3); 
g_R = paramsModel.para(4);
K_A = paramsModel.para(5);
K_R = paramsModel.para(6);
K = paramsModel.para(7);
H = paramsModel.para(8);
Da = paramsModel.para(9);
Dr = paramsModel.para(10);

Dr_lst = 3.6* logspace(-0.5, 3.5, 9);

for j = 1:size(Dr_lst,2)
    %% Steady state

    A0 = 0;%a_A/g_A;%a_p / c_p;
    R0 = 0;%a_R/g_R;

    tspan = [0 10000];
    y0 = 0.1;
    [t, y] = ode45(@(t, y) a_A * ((y./K_A).^H + (1/K).^H)./((y./K_A).^H + ((g_A * a_R * y./(g_R * a_A))./K_R).^H + 1 + (1/K).^H) - g_A * y, tspan, y0);
    As = y(end);
    Rs =  g_A * a_R * As/(g_R * a_A);

    dAdt = a_A * ((As/K_A).^H + (1/K).^H)./((As/K_A).^H + (Rs/K_R).^H + 1 + (1/K).^H) - g_A * As;
    dRdt = a_R * ((As/K_A).^H + (1/K).^H)./((As/K_A).^H + (Rs/K_R).^H + 1 + (1/K).^H) - g_R * Rs;

    denom2 = ((As/K_A)^H + (Rs/K_R)^H + 1 + (1/K)^H)^2;
    dFdA = H*(As/K_A)^(H-1)*((Rs/K_R)^H + 1)/K_A/denom2;
    dFdR = -H*(Rs/K_R)^(H-1)*((As/K_A)^H + (1/K)^H)/K_R/denom2;

    J = [dFdA * a_A - g_A, dFdR * a_A; dFdA * a_R, dFdR * a_R - g_R];
    eig(J);
    B = [Da, 0; 0, Dr_lst(j)];

    % 1-D
    k = 1:w;
    qk = -4*sin(k*pi/(w)).^2;

    dispCuv = zeros(w);
    for i = 1:w
        dispCuv(i) = max(real(eig(J + qk(i)* B)));
    end
    dispCuv = dispCuv/max(dispCuv);
    Curvs(j,:) = dispCuv(1:w/2);
end

gausWinSize = round(5*logspace(0,1.6,9));
%% 

for j = 1:size(Dr_lst,2)
    filename = sprintf('Fig3DFdata/Fig3DF_Dr%08.2f_t200_reflective_LA_TI0Pos1_20x1000.mat', Dr_lst(j));
    res = load(filename);
    Za = res.results.Za;
    ZaEnd = res.results.Za(:,:,end);
    Aend = mean(ZaEnd, 1);
    ZaW = mean(Za,1);

    A_totalcorr = xcorr(Aend','coeff');
    A_corr = A_totalcorr((size(A_totalcorr,1)+1)/2:end);
    w = gausswin(gausWinSize(j));
    A_fltr = filter(w,1,A_corr);
    [Acorr_maxima,Acorr_maxIdx] = findpeaks(A_fltr);
    maxID = [Acorr_maxima,Acorr_maxIdx];

    if size(maxID,1)>5
        maxID = maxID(1:5,:);
    end

    wlgth = (maxID(end,2) - maxID(1,2))/(size(maxID,1) - 1);
    wvnmbr = 1000/wlgth;
    krange(j,:) = [round(1000/(wlgth + 1)), round(wvnmbr), round(1000/(wlgth - 1))];

end


%%
figure;
cmap = [linspace(0.3,0,9);linspace(0.3,1,9);linspace(0.3,1,9);linspace(0.5,0.5,9)]';
hold on
for j = 1:9
    plot(Curvs(j,:),'color',cmap(j,:),'lineWidth',1);
    line([krange(j,2) krange(j,2)], [-0.4 1.1],'color',cmap(j,:),'lineWidth',0.5);
end
x = krange(:,2);
y = diag(Curvs(:,krange(:,2)));
xneg = x - krange(:,1);
xpos = krange(:,3) - x;
yneg = y - diag(Curvs(:,krange(:,1)));
ypos = diag(Curvs(:,krange(:,3))) - y;
errorbar(x,y,yneg,ypos,xneg,xpos,'o', 'MarkerSize',5, ...
    'MarkerFaceColor','none','MarkerEdgeColor','red','lineWidth',1);
% line([1 500],[0 0],'color','k','LineWidth',0.5);
set(gca, 'xscale','log');
xlabel('wavenumber k')
ylabel('Re(\lambda)_{max}')
ylim([-0.4, 1.1]);
xlim([1, 500]);
box on;
hold off

figname = sprintf('Fig3DFplot/Fig3F');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));

