%% Simulation for data in 4C 
% Simulation platform for the SMRD paper 2C1D + LA + with noise


disp('Model setup...')
tic
%% model setup
model = @Kinetics_squ_SMRD;

%% System parameters
paramsSys.L = 0.5;                       % Half-Size of cell population
paramsSys.W = 200;
paramsSys.N = 4 * paramsSys.L * paramsSys.W;      % Total number of cells will be 2Lx2W
paramsSys.numSpecies = 2;               % number of species in model
paramsSys.bdryType = 'reflective';  % boundary condition type ( Twist-periodic; periodic; reflective)
paramsSys.TgrType = 'LA';   % trigger type ('RN': global random noise; 'SP': single point; 'LA': line activation)
paramsSys.TgrPos = 1;%paramsSys.W;         % trigger position (The left-right position) 
paramsSys.TgrInts = 0;                  % trigger intensity (In 'SP', 'LA': conc.x(1+2^(-paramsSys.TgrInts)); In 'RN': conc.x(1 + 0.01xTgrIntsxrand());) 

%% Simulation parameters
paramsSys.resetCycle = 1;
paramsSys.tSpanMax = 100;
paramsSys.tStep = 0.1;
paramsSys.tSpan = 0 : paramsSys.tStep : paramsSys.tSpanMax; %paramsSys.tSpanMax/50 : paramsSys.tSpanMax;       % time steps over which main simulation should be run *per iteration*, after which steady state check is performed
paramsSys.maxT = paramsSys.tSpanMax;               % maxmimum main simulation start time (simulation will not re-run if not at steay-state by maxT
paramsSys.tSpanPre = [0 60];         % timespan over which pre-equilibration simulation should be run *per iteration*, after which steady state check is performed
paramsSys.maxTPre = 14400;           % maxmimum pre-eqilibration simulation start time (simulation will not re-run if not at steay-state by maxT

paramsSys.simChunkSize = 5000;          % number of simulations per chunk (i.e., between saves).  If running out of memory, decrease simChunkSize
paramsSys.minTimeSteps = 10;            % minimum number of time steps before solver considers terminating due to being at steady-state
paramsSys.steadyStateTol = 10^-5;       % largest value of fractional difference in concentrations at any y between adjacent timepoints, over the last sSLookbackSteps, below which system is at steady-state
paramsSys.sSLookbackSteps = 10;         % number of steps to look back in determining whether at steady-state.  Must be <= minTimeSteps
paramsSys.tMin = 24*60;                 % minimum time ode15s has to simulate before steay-state is considered
paramsSys.rdcell = randn(paramsSys.N,1);

filename = sprintf('QSmat_%s_%dx%d.mat',paramsSys.bdryType,2*paramsSys.L,2*paramsSys.W);
if ~isempty(filename) && ~isempty(dir(filename))
    QS_mtx = load(filename);
    paramsSys.Trans = QS_mtx.trans;
    paramsSys.Q = QS_mtx.Q;
    paramsSys.S = QS_mtx.S;
else
    [paramsSys.Trans, paramsSys.Q, paramsSys.S] = gen_QS(paramsSys);
end

%% Model parameters
paramsModel.a_A = 100;%100;
paramsModel.a_R = 80;%80;

paramsModel.g_A = 1.5;%1.5; 
paramsModel.g_R = 0.5;%0.5;

paramsModel.K_A = 10;
paramsModel.K_R = 10;
paramsModel.K = 10;
paramsModel.H = 2;
paramsModel.Dr = 3.6;

paramsModel.CutOff = 1e-13 ;

tn = [0,20,100];
rp = 1:1:20;
[X,Y] = meshgrid(tn, rp);
para_lst = [X(:), Y(:)];
NumCont = size(para_lst,1);  

toc
%% run simulation
disp('Start running simulation...')

if ~exist('Fig4CDdata', 'dir')
   mkdir Fig4CDdata
end

parfor cont = 1:NumCont
    results = modelSim_squ_SMRD(model, para_lst(cont,:), paramsModel, paramsSys, 0, 0, 0, 0);
end
