%% Loading data

GC = 'growthCoupled/GCdata/varNoise_CorrData_GC.mat';
IR = 'IR4/IRdata/varNoise_CorrData_IR.mat';
MNHS = 'minimal_from_hs/MN_HSdata/varNoise_CorrData_MN_HS.mat';
MNFP = 'minimal_from_fp/MN_FPdata/varNoise_CorrData_MN_FP.mat';
%%
para_lst = {MNHS,MNFP,'4E';MNHS,IR,'5F';MNHS,GC,'6E'};


% para_lst = {'MNdu','MNaf','4F';'MNdu','IR','5J';'MNdu','GC','6G'};
for i =1:3
    noiseRobustCurve(para_lst(i,:));
end

function noiseRobustCurve(para)
    ContrFile  = sprintf('%s',char(para(1)));
    SampFile  = sprintf('%s',char(para(2)));
    Contr = load(ContrFile);
    Samp = load(SampFile);
    Dataname = char(para(3));

    linlog_bdry = 1e-8;
    intensity_lst = 10.^[-1, -1.5, -2, -2.5, -3, -4, -5, -6, -7, -8];
    x_sig = - intensity_lst;
    x_eta = flip(intensity_lst);
    x_mid = [-linlog_bdry, 0, linlog_bdry];
    y1 = flip(mean(Contr.coefR_sig,1));
    y2 = mean(Contr.coefR_eta,1);
    y3 = flip(mean(Samp.coefR_sig,1));
    y4 = mean(Samp.coefR_eta,1);
    std1 = flip(std(Contr.coefR_sig,1));
    std2 = std(Contr.coefR_eta,1);
    std3 = flip(std(Samp.coefR_sig,1));
    std4 = std(Samp.coefR_eta,1);
    y_sigC = y1(1:end-1);
    y_sigS = y3(1:end-1);
    std_sigC = std1(1:end-1);
    std_sigS = std3(1:end-1);
    y_etaC = y2(2:end);
    y_etaS = y4(2:end);
    std_etaC = std2(2:end);
    std_etaS = std4(2:end);
    y_midC = [y1(end-1:end),y2(2)];
    y_midS = [y3(end-1:end),y4(2)];
    std_midC = [std1(end-1:end),std2(2)];
    std_midS = [std3(end-1:end),std4(2)];
    %%
    h = figure;
    ax1 = subplot(131);
    hold on
    plot(x_sig,y_sigC,'o-');
    plot(x_sig,y_sigS,'o-');
    patch([x_sig';flipud(x_sig')],[y_sigC'-std_sigC'; flipud(y_sigC'+std_sigC')],[0.6,0.7,0.8], ...
        'FaceAlpha', 0.2, 'EdgeColor','none');
    patch([x_sig';flipud(x_sig')],[y_sigS'-std_sigS'; flipud(y_sigS'+std_sigS')],[0.6,0.2,0.1], ...
        'FaceAlpha', 0.2, 'EdgeColor','none');
    hold off

    ax2 = subplot(132);
    hold on
    plot(x_mid,y_midC,'o-');
    plot(x_mid,y_midS,'o-');
    patch([x_mid';flipud(x_mid')],[y_midC'-std_midC'; flipud(y_midC'+std_midC')],[0.6,0.7,0.8], ...
        'FaceAlpha', 0.2, 'EdgeColor','none');
    patch([x_mid';flipud(x_mid')],[y_midS'-std_midS'; flipud(y_midS'+std_midS')],[0.6,0.2,0.1], ...
        'FaceAlpha', 0.2, 'EdgeColor','none');    
    hold off
    xlabel('NosInts');
    
    ax3 = subplot(133);
    hold on

    plot(x_eta,y_etaC,'o-');
    plot(x_eta,y_etaS,'o-');
    patch([x_eta';flipud(x_eta')],[y_etaC'-std_etaC'; flipud(y_etaC'+std_etaC')],[0.6,0.7,0.8], ...
        'FaceAlpha', 0.2, 'EdgeColor','none');
    patch([x_eta';flipud(x_eta')],[y_etaS'-std_etaS'; flipud(y_etaS'+std_etaS')],[0.6,0.2,0.1], ...
        'FaceAlpha', 0.2, 'EdgeColor','none');
    hold off
    
    set(ax1,'units','normalized','position',[0.15 0.1 0.3 0.8]);
    set(ax2,'units','normalized','position',[0.45 0.1 0.1 0.8]);
    set(ax3,'units','normalized','position',[0.55 0.1 0.3 0.8]);
    set(ax1,'xscale','log','xlim',[-1, -linlog_bdry]);
    set(ax2,'xscale','linear','xlim',[-linlog_bdry linlog_bdry]);
    set(ax3,'xscale','log','xlim',[linlog_bdry 1]);
    set(ax2,'xlim',[-linlog_bdry, linlog_bdry],'xtick',-linlog_bdry:linlog_bdry:linlog_bdry,'xticklabel',{'', '', ''});
    set([ax1 ax2 ax3],'ylim',[-0.1 1.1],'ytick',0:0.2:1.0,'box','off');
    set(ax2,'yticklabel','','YColor','w');
    set(ax3,'yticklabel','','YColor','w');
    set([ax1 ax2 ax3],'gridColor','b');
    uistack(ax1,'top');
    grid(ax1,'on');
    grid(ax2,'on');
    grid(ax3,'on');
    figname = sprintf('Fig%s',Dataname);
    saveas(gca, strcat(figname,'.fig'));
    saveas(gca, strcat(figname,'.png'));
end