%% Plot Fig5B left

if ~exist('Fig5Bplot', 'dir')
   mkdir Fig5Bplot
end

a_A = 100;
a_R = 80;
g_A = 1.5; 
g_R = 0.5;
g_P = 0.1;
K_A = 10;
K_R = 10;
K_T = 2.5; 
K_P = 0.1; 
K = 10;
H = 2;
Dr = 3.6;

f = @(t,Y)[a_A * ((Y(1)/K_A)^H + (1/K)^H)/((Y(1)/K_A)^H + (Y(2)/K_R)^H + 1 + (1/K)^H) - g_A * Y(1) - 3 * (1 - Y(3)) * Y(1); ...
    a_R * ((Y(1)/K_A)^H + (1/K)^H)/((Y(1)/K_A)^H + (Y(2)/K_R)^H + 1 + (1/K)^H) - g_R * Y(2); ...
    Y(3)^2/(Y(3)^2+K_P^2) + 0.01 * (abs(Y(2)-K_T) + (Y(2)-K_T))/(abs(Y(2)-K_T)+eps) - Y(3)];

%% phase portrait in A-R-P space

y1rg = logspace(-1,2,31); % A = [0, 60]
y2rg = logspace(-1,2,31); % R = [0, 70]
y3rg = [0,logspace(-4, 0.01, 31)]; % P = [0,1]
%%
[A,R,P] = meshgrid(y1rg, y2rg, y3rg);
IniPoint = [A(:), R(:), P(:)];

dAdt = a_A  .* ((A/K_A).^H + (1/K).^H)./((A/K_A).^H + (R/K_R).^H + 1 + (1/K).^H) - g_A * A - 3 * (1 - P) .* A; 
dRdt = a_R  .* ((A/K_A).^H + (1/K).^H)./((A/K_A).^H + (R/K_R).^H + 1 + (1/K).^H) - g_R * R;
dPdt = P.^2./(P.^2+K_P.^2) + 0.01 * (abs(R-K_T) + (R-K_T))./(abs(R-K_T)+eps) - P;

sssReg = zeros(size(y1rg,2),size(y2rg,2),size(y3rg,2));
for i = 1:size(y1rg,2)
    for j = 1:size(y2rg,2) 
        for k = 1:size(y3rg,2)
            [ts,Ys] = ode45(f, [0,50],[y1rg(i),y2rg(j),y3rg(k)]);
            if Ys(end,3) < 0.5
                sssReg(i,j,k) = 1;
            end
        end
    end
end
%%
bdy_pts = [0,0,0];
for i = 1:size(y1rg,2)-1
    for j = 1:size(y2rg,2)-1 
        for k = 1:size(y3rg,2)-1
            if (sssReg(i,j,k) > 0.5) && (sssReg(i,j,k+1) < 0.5)
                sssReg(i,j,k+1) = 0.5;
                bdy_pts = [bdy_pts; i,j,k];
            end
        end
    end
end
bdy_pts = bdy_pts(2:end,:);
%%
sss_pts = [0,0,0];
rds_pts = [0,0,0];
for i = 1:size(y1rg,2)
    for j = 1:size(y2rg,2) 
        for k = 1:size(y3rg,2)
            if sssReg(i,j,k) > 0.4
                sss_pts = [sss_pts; i,j,k];
            end
            if sssReg(i,j,k) < 0.6
                rds_pts = [rds_pts; i,j,k];
            end
        end
    end
end
sss_pts = sss_pts(2:end,:);
rds_pts = rds_pts(2:end,:);

%% Endpoints

[ts,Ys] = ode45(f, [0,50],[y1rg(1),y2rg(1),y3rg(1)]);
ep1 = log10(Ys(end,:));
Endpoint1 = [29*(ep1(1)+1)/3+1,29*(ep1(2)+1)/3+1,1];

[ts,Ys] = ode45(f, [0,50],[y1rg(end),y2rg(end),y3rg(end)]);
ep2 = log10(Ys(end,:));
Endpoint2 = [29*(ep2(1)+1)/3+1,29*(ep2(2)+1)/3+1,30*(ep2(3)+4)/4.01+2];

%%
figure;
hold on

shp_sss = alphaShape(sss_pts(:,1), sss_pts(:,2), sss_pts(:,3),5);
shp_rds = alphaShape(rds_pts(:,1), rds_pts(:,2), rds_pts(:,3),5);

plot(shp_sss,'FaceColor',[202,178,214]/255,'FaceAlpha',0.3,'EdgeColor','none');
plot(shp_rds,'FaceColor',[253,191,111]/255,'FaceAlpha',0.1,'EdgeColor','none');

scatter3(Endpoint1(1),Endpoint1(2),Endpoint1(3), 100.0,[106,61,154]/255,'filled','MarkerFaceAlpha', 1);
scatter3(Endpoint2(1),Endpoint2(2),Endpoint2(3), 100.0,[255,127,0]/255,'filled','MarkerFaceAlpha', 1);

xm = 31;
ym = 31;
zm = 32;
xlim([1,xm]);
xlabel('A (nM)');
xticks(linspace(1,31,4));
xticklabels(string(roundn((10.^(linspace(-1,2,4))),-1)));
ylim([1,ym]);
ylabel('R (nM)');
yticks(linspace(1,31,4));
yticklabels(string(roundn((10.^(linspace(-1,2,4))),-1)));
zlim([1,zm]);
zlabel('M*/Mtotal');
zticks([1,linspace(2,32,5)]);
zticklabels({'0','1E-4','1E-3','1E-2','1E-1','1'});
box on

boxline1 = line([1 xm], [1 1], [zm zm],'Color','black','LineWidth',0.5);
boxline2 = line([xm xm],[1 ym], [zm zm],'Color','black','LineWidth',0.5);
boxline3 = line([xm xm],[1 1], [1 zm],'Color','black','LineWidth',0.5);
boxline1.Color(4) = 0.5;
boxline2.Color(4) = 0.5;
boxline3.Color(4) = 0.5;
hold off

figname = sprintf('Fig5Bplot/Fig5B_phasePortrait.fig');
saveas(gca,figname);


%% Model parameters
paramsModel.para = [100, 80, 1.5, 0.5, 10, 10, 10, 2, 0, 3.6];

w = 60;

a_A = paramsModel.para(1);
a_R = paramsModel.para(2);

g_A = paramsModel.para(3); 
g_R = paramsModel.para(4);

K_A = paramsModel.para(5);
K_R = paramsModel.para(6);
K = paramsModel.para(7);
H = paramsModel.para(8);
Da = paramsModel.para(9);
Dr = paramsModel.para(10);

gA_lst = [1.5, 4.5];%logspace(0, 3.5, 8);
color_lst = [0.75,0,0;0,0.5,0.75];
figure
hold on
for j = 1:size(gA_lst,2)
    %% Steady state


    g_A = gA_lst(j);
    tspan = [0 10000];
    y0 = 0;
    [t, y] = ode45(@(t, y) a_A * ((y./K_A).^H + (1/K).^H)./((y./K_A).^H + ((g_A * a_R * y./(g_R * a_A))./K_R).^H + 1 + (1/K).^H) - g_A * y, tspan, y0);
    As = y(end);
    Rs =  g_A * a_R * As/(g_R * a_A);

    denom2 = ((As/K_A)^H + (Rs/K_R)^H + 1 + (1/K)^H)^2;
    dFdA = H*(As/K_A)^(H-1)*((Rs/K_R)^H + 1)/K_A/denom2;
    dFdR = -H*(Rs/K_R)^(H-1)*((As/K_A)^H + (1/K)^H)/K_R/denom2;

    J = [dFdA * a_A - g_A, dFdR * a_A; dFdA * a_R, dFdR * a_R - g_R];
    B = [Da, 0; 0, Dr];

    % 1-D
    k = 0:w-1;
    qk = -4*sin(k*pi/(w)).^2;

    dispCuv = zeros(w,1);
    for i = 1:w
        dispCuv(i) = max(real(eig(J + qk(i)* B)));
    end
    dispCuv = dispCuv/max(abs(dispCuv));
%     plot(dispCuv);

    plot(0:w/2-1, dispCuv(1:w/2),'o-','color',color_lst(j,:));
end

line([0 30],[0 0],'color','k');
xlabel('wavenumber k')
ylabel('Re(\lambda)')
ylim([-1.5, 1.5]);
hold off

figname = sprintf('Fig5Bplot/Fig5B_dispersionCurve');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));

