%% Plot Fig5CDE

filename = sprintf('../Fig4E5F6E/inhibitionRelease/IRdata/Dr3.60_t600_reflective_LA_sig0.00000000eta0.00000000_1x400_trail1.mat');
res = load(filename);
y = res.results.y;
y0 = res.results.yPre;
Za = squeeze(res.results.Za);
Zr = squeeze(res.results.Zr);
Zp = squeeze(res.results.Zp);

whitered = [linspace(1,1,256); linspace(1,0.3,256); linspace(1,0.3,256)]';
whitegreen = [linspace(1,0.2,256); linspace(1,0.8,256); linspace(1,0.2,256)]';
whiteblue = [linspace(1,0,256); linspace(1,0.5,256); linspace(1,1,256)]';

Xl = 1;
Xr = 100;
t = 120*5;%145;
x = Xl:Xr;

figure;
hold on
yyaxis left
plot(x, Za(Xl:Xr,t), '-','lineWidth',2,'Color',[1,0.3,0.3,0.3]);
plot(x, Zr(Xl:Xr,t), '-','lineWidth',2,'Color',[0.2,0.8,0.2,0.3]);
plot(x, Za(Xl:Xr,t), 'o','lineWidth',2,'Color',[1,0.3,0.3,1]);
plot(x, Zr(Xl:Xr,t), 'o','lineWidth',2,'Color',[0.2,0.8,0.2,1]);
ylabel('[A], [R]');
ylim([0,50]);
set(gca,'ycolor','k');
yyaxis right
plot(x, Zp(Xl:Xr,t), '-','lineWidth',2,'Color',[0,0.5,1,0.3]);
plot(x, Zp(Xl:Xr,t), 'o','lineWidth',2,'Color',[0,0.5,1,1]);
ylabel('[P]');
ylim([0,1.1]);
set(gca,'ycolor','k');
xlabel('cell number in x-axis');
title('t = 120 h');
box on;
hold off

figname = sprintf('Fig5C');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));

%% Fig 5D
X0 = 200;
t = 300*5;

figure;
ax1 = subplot(3,1,1);
imagesc(Za(1:X0,1:t)');
title('[A]');
xlabel('Cell position in x (cell number)');
ylabel('Time (h)');
set(gca,'YTick',0:500:1000,'YTicklabel',0:100:200);
caxis([0, 50]);
colormap(ax1, whitered);
colorbar;

ax2 = subplot(3,1,2);
imagesc(Zr(1:X0,1:t)');
title('[R]');
xlabel('Cell position in x (cell number)');
ylabel('Time (h)');
set(gca,'YTick',0:500:1000,'YTicklabel',0:100:200);
caxis([0, 50]);
colormap(ax2, whitegreen);
colorbar;

ax3 = subplot(3,1,3);
imagesc(Zp(1:X0,1:t)');
title('[P]');
xlabel('Cell position in x (cell number)');
ylabel('Time (h)');
set(gca,'YTick',0:500:1000,'YTicklabel',0:100:200);
caxis([0, 1]);
colormap(ax3, whiteblue);
colorbar;

figname = sprintf('Fig5D');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));

%% Fig5E
a_A = 100;%100;
a_R = 80;%80;

g_A = 1.5;%1.5; 
g_R = 0.5;%0.5;
g_P = 0.1; 

K_A = 10;
K_R = 10;

K_T = 2.5; 
K_P = 0.1; 

K = 10;
H = 2;

f = @(t,Y)[a_A * ((Y(1)/K_A)^H + (1/K)^H)/((Y(1)/K_A)^H + (Y(2)/K_R)^H + 1 + (1/K)^H) - g_A * Y(1) - 3 * (1 - Y(3)) * Y(1); ...
    a_R * ((Y(1)/K_A)^H + (1/K)^H)/((Y(1)/K_A)^H + (Y(2)/K_R)^H + 1 + (1/K)^H) - g_R * Y(2) + 1.5* (abs(t-1)+(1-t)); ...
    Y(3)^2/(Y(3)^2+K_P^2) + 0.01 * (abs(Y(2)-K_T) + (Y(2)-K_T))/(abs(Y(2)-K_T)+eps) - Y(3)];

ini_state = y(1,end-2:end);
[ts,Ys] = ode45(f, [0,50],ini_state);  

kymoA = Za';
kymoR = Zr';
kymoP = Zp';

figure;
hold on
MarkerSize = 30;
for i = 100:180%size(y,2)/3
    plot(kymoA(:,i),kymoR(:,i),'color',[0.5,0.5,0,1],'lineWidth',0.3);
    if kymoA(end,i) > 10
        scatter(kymoA(end,i),kymoR(end,i), MarkerSize,'filled', ...
            'MarkerEdgeColor', [0.5,0,0],'MarkerFaceColor', [1,0.3,0.3],'LineWidth',1);
    else
        scatter(kymoA(end,i),kymoR(end,i), MarkerSize,'filled', ...
            'MarkerEdgeColor', [0,0.5,0],'MarkerFaceColor', [0.2,0.8,0.2],'LineWidth',1);
    end
    scatter(kymoA(1,i),kymoR(1,i), MarkerSize,'filled','MarkerFaceColor',[83,71,84]/256);
end

plot(Ys(:,1),Ys(:,2),'color', [0,0,0.5,1],'lineWidth',1);
scatter(Ys(end,1),Ys(end,2), MarkerSize,'filled', ...        
        'MarkerEdgeColor', [247, 148, 29]/255,'MarkerFaceColor', [253, 191, 110]/255,'LineWidth',1);
scatter(Ys(1,1),Ys(1,2), MarkerSize,'filled', ...
        'MarkerEdgeColor', [127, 63, 152]/255,'MarkerFaceColor', [212, 180, 213]/255,'LineWidth',1);
    
hold off
xlim([0.05,100])
ylim([1,100])
set(gca,'xscale','log');
set(gca,'yscale','log');
xlabel('[A] (nM)')
ylabel('[R] (nM)')
box on;

figname = sprintf('Fig5E');
saveas(gca, strcat(figname,'.fig'));
saveas(gca, strcat(figname,'.png'));