%% Simulation for data in 6D
% Simulation platform for the SMRD paper 2C1D(growth-coupled) + LA + no noise

disp('Model setup...')
tic
%% model setup
model = @Kinetics_squ_SMRD_GroCou;

%% System parameters
paramsSys.L0 = 1;                       % Half-Size of cell population
paramsSys.Lt = 200;                       % Half-Size of cell population
paramsSys.W = 0.5;
paramsSys.N0 = 4 * paramsSys.L0 * paramsSys.W;      % Total number of cells will be 2Lx2W
paramsSys.Nt = 4 * paramsSys.Lt * paramsSys.W;      % Total number of cells will be 2Lx2W
paramsSys.numSpecies = 2;               % number of species in model
paramsSys.bdryType = 'reflective';  % boundary condition type ( Twist-periodic; periodic; reflective)
paramsSys.TgrType = 'csLA';   % trigger type ('RN': global random noise; 'SP': single point; 'LA': line activation)
paramsSys.TgrPos = paramsSys.W;         % trigger position (The left-right position) 
paramsSys.TgrInts = 0;                  % trigger intensity (In 'SP', 'LA': conc.x(1+2^(-paramsSys.TgrInts)); In 'RN': conc.x(1 + 0.01xTgrIntsxrand());) 

%% Simulation parameters
paramsSys.resetCycle = 2 * (paramsSys.Lt-paramsSys.L0);

paramsSys.tSpanPre = [0 60];         % timespan over which pre-equilibration simulation should be run *per iteration*, after which steady state check is performed
paramsSys.maxTPre = 14400;           % maxmimum pre-eqilibration simulation start time (simulation will not re-run if not at steay-state by maxT

paramsSys.simChunkSize = 5000;          % number of simulations per chunk (i.e., between saves).  If running out of memory, decrease simChunkSize
paramsSys.minTimeSteps = 10;            % minimum number of time steps before solver considers terminating due to being at steady-state
paramsSys.steadyStateTol = 10^-5;       % largest value of fractional difference in concentrations at any y between adjacent timepoints, over the last sSLookbackSteps, below which system is at steady-state
paramsSys.sSLookbackSteps = 10;         % number of steps to look back in determining whether at steady-state.  Must be <= minTimeSteps
paramsSys.tMin = 24*60;                 % minimum time ode15s has to simulate before steay-state is considered
paramsSys.rdcell = randn(paramsSys.Nt,1);

%% Model parameters
paramsModel.a_A = 100;%100;
paramsModel.a_R = 80;%80;

paramsModel.g_A = 1.5;%1.5; 
paramsModel.g_R = 0.5;%0.5;

paramsModel.K_A = 10;
paramsModel.K_R = 10;
paramsModel.K = 10;
paramsModel.H = 2;
paramsModel.Dr = 3.6;

paramsModel.CutOff = 1e-13 ; % scale ~ sensitivity

GR_lst = [0.4, 0.6, 0.8, 1, 1.5, 2, 4, 8];
Dr_lst  = 3.6*[10^0, 10^0.25, 10^0.5, 10^0.75, 10^1.0, 10^1.25, 10^1.5, 10^1.75, 10^2];
[X, Y] = meshgrid(GR_lst, Dr_lst);
para_lst = [X(:), Y(:)];
NumCont = size(para_lst,1);

toc
%% run simulation
disp('Start running simulation...')

if ~exist('Fig6Ddata', 'dir')
   mkdir Fig6Ddata
end

parfor cont = 1:NumCont
    results = modelSim_squ_SMRD_GroCou(model, para_lst(cont,:), paramsModel, paramsSys, 1, 0, 0, 0);
end
