%% 2C1Dftpal (final::pre-equilibrium::almighty-plotting::lite)
% Edit from 200216_2C1DfModel_CodeSimplify
% final:: Full parameter model for final 2C1D circuit
% Turbo:: Use Laplacian matrix Q and Jacobian sparsity matrix S to simulate faster
% Pre-equilibrium:: calculate the steady state of non-diffusion case to start equilibrium
% Almighty-plot ting:: plot final steady state of two conponent, movie and kymogragh
% Lite:: remove redundent part of the code from Joe's version

disp('Model setup...')
tic
%% model setup
model = @TuringGM_squ_SMRD;

%% System parameters
paramsSys.L = 30.5;                       % Half-Size of cell population
paramsSys.W = 30.5;
paramsSys.N = 4 * paramsSys.L * paramsSys.W;      % Total number of cells will be 2Lx2W
paramsSys.numSpecies = 2;               % number of species in model
paramsSys.bdryType = 'reflective';  % boundary condition type ( Twist-periodic; periodic; reflective)
paramsSys.TgrType = 'LA';   % trigger type ('RN': global random noise; 'SP': single point; 'LA': line activation)
paramsSys.TgrPos = paramsSys.W;         % trigger position (The left-right position) 
paramsSys.TgrInts = 1;                  % trigger intensity (In 'SP', 'LA': conc.x(1+2^(-paramsSys.TgrInts)); In 'RN': conc.x(1 + 0.01xTgrIntsxrand());) 

%% Simulation parameters
% t_lst = [50, 20, 50, 100, 200, 400, 800];
paramsSys.resetCycle = 1;
paramsSys.tSpanMax = 100;
paramsSys.tStep = 2;
paramsSys.tSpan = 0 : paramsSys.tStep : paramsSys.tSpanMax; %paramsSys.tSpanMax/50 : paramsSys.tSpanMax;       % time steps over which main simulation should be run *per iteration*, after which steady state check is performed
paramsSys.maxT = paramsSys.tSpanMax;               % maxmimum main simulation start time (simulation will not re-run if not at steay-state by maxT
paramsSys.tSpanPre = [0 60];         % timespan over which pre-equilibration simulation should be run *per iteration*, after which steady state check is performed
paramsSys.maxTPre = 14400;           % maxmimum pre-eqilibration simulation start time (simulation will not re-run if not at steay-state by maxT

paramsSys.simChunkSize = 5000;          % number of simulations per chunk (i.e., between saves).  If running out of memory, decrease simChunkSize
paramsSys.minTimeSteps = 10;            % minimum number of time steps before solver considers terminating due to being at steady-state
paramsSys.steadyStateTol = 10^-5;       % largest value of fractional difference in concentrations at any y between adjacent timepoints, over the last sSLookbackSteps, below which system is at steady-state
paramsSys.sSLookbackSteps = 10;         % number of steps to look back in determining whether at steady-state.  Must be <= minTimeSteps
paramsSys.tMin = 24*60;                 % minimum time ode15s has to simulate before steay-state is considered
paramsSys.rdcell = randn(paramsSys.N,1);

filename = sprintf('QSmat_%s_%dx%d.mat',paramsSys.bdryType,2*paramsSys.L,2*paramsSys.W);
if ~isempty(filename) && ~isempty(dir(filename))
    QS_mtx = load(filename);
    paramsSys.Trans = QS_mtx.trans;
    paramsSys.Q = QS_mtx.Q;
    paramsSys.S = QS_mtx.S;
else
    [paramsSys.Trans, paramsSys.Q, paramsSys.S] = gen_QS(paramsSys);
end

%% Model parameters

paramsModel.D = 3;
paramsModel.k = [0.1,1,1,1,1];
paramsModel.CutOff = 0 ;
para_lst = {'RN','LA','SP'};
toc
%% run simulation
disp('Start running simulation...')
if ~exist('SFig1data', 'dir')
   mkdir SFig1data
end
parfor cont = 1:size(para_lst,2)
    results = modelSim_squ_SMRD(model, para_lst(cont), paramsModel, paramsSys, 0, 0, 0, 0);
end

