%% 3C1Dftpal (final::pre-equilibrium::almighty-plotting::lite)
% Edit from 200416_2C1Dftpal_LI_OUSP
% final:: Full parameter model for final 3C1D circuit
% Turbo:: Use Laplacian matrix Q and Jacobian sparsity matrix S to simulate faster
% Pre-equilibrium:: calculate the steady state of non-diffusion case to start equilibrium
% Almighty-plot ting:: plot final steady state of two conponent, movie and kymogragh
% Lite:: remove redundent part of the code from Joe's version

disp('Model setup...')
tic
%% model setup
model = @Turing_squ_3C1Dftpal;

%% System parameters
paramsSys.L = 30.5;                       % Half-Size of cell population
paramsSys.W = 30.5;
paramsSys.N = 4 * paramsSys.L * paramsSys.W;      % Total number of cells will be 2Lx2W
paramsSys.numSpecies = 3;               % number of species in model
paramsSys.bdryType = 'reflective';  % boundary condition type ( Twist-periodic; periodic; reflective)
paramsSys.TgrType = 'SP';   % trigger type ('RN': global random noise; 'SP': single point; 'LA': line activation)
paramsSys.TgrPos = 0;%paramsSys.W;         % trigger position (The left-right position) 
paramsSys.TgrInts = 0;                  % trigger intensity (In 'SP', 'LA': conc.x(1+2^(-paramsSys.TgrInts)); In 'RN': conc.x(1 + 0.01xTgrIntsxrand());) 

%% Simulation parameters
% t_lst = [50, 20, 50, 100, 200, 400, 800];
paramsSys.resetCycle = 1;
paramsSys.tSpanMax = 200;
paramsSys.tStep = 2;
paramsSys.tSpan = 0 : paramsSys.tStep : paramsSys.tSpanMax; %paramsSys.tSpanMax/50 : paramsSys.tSpanMax;       % time steps over which main simulation should be run *per iteration*, after which steady state check is performed
paramsSys.maxT = paramsSys.tSpanMax;               % maxmimum main simulation start time (simulation will not re-run if not at steay-state by maxT
paramsSys.tSpanPre = [0 60];         % timespan over which pre-equilibration simulation should be run *per iteration*, after which steady state check is performed
paramsSys.maxTPre = 14400;           % maxmimum pre-eqilibration simulation start time (simulation will not re-run if not at steay-state by maxT

paramsSys.simChunkSize = 5000;          % number of simulations per chunk (i.e., between saves).  If running out of memory, decrease simChunkSize
paramsSys.minTimeSteps = 10;            % minimum number of time steps before solver considers terminating due to being at steady-state
paramsSys.steadyStateTol = 10^-5;       % largest value of fractional difference in concentrations at any y between adjacent timepoints, over the last sSLookbackSteps, below which system is at steady-state
paramsSys.sSLookbackSteps = 10;         % number of steps to look back in determining whether at steady-state.  Must be <= minTimeSteps
paramsSys.tMin = 24*60;                 % minimum time ode15s has to simulate before steay-state is considered
paramsSys.rdcell = randn(paramsSys.N,1);

filename = sprintf('QSmat_%s_%dx%d.mat',paramsSys.bdryType,2*paramsSys.L,2*paramsSys.W);
if ~isempty(filename) && ~isempty(dir(filename))
    QS_mtx = load(filename);
    paramsSys.Trans = QS_mtx.trans;
    paramsSys.Q = QS_mtx.Q;
    paramsSys.S = QS_mtx.S;
else
    [paramsSys.Trans, paramsSys.Q, paramsSys.S] = gen_QS(paramsSys);
end

%% Model parameters
p1 = [33,33,27,0.3,0.3,0.36];
p2 = [100,100,80,0.5,0.5,0.6];
p3 = [100,80,80,0.4,0.5,0.6];
p = [100,80,80,0.4,0.6,0.6];

paramsModel.a_A = p(1);%100;%20000;
paramsModel.a_R = p(2);%100;%20000;
paramsModel.a_M = p(3);%80;%16000;

paramsModel.r_A = p(4);%0.5; 
paramsModel.r_R = p(5);%0.5;
paramsModel.r_M = p(6);%0.6;

paramsModel.D = 3.6;%12.0;
paramsModel.K1 = 10;
paramsModel.K2 = 10;%10000;
% paramsModel.kap = 0.1;
paramsModel.H1 = 2;
paramsModel.H2 = 2;

paramsModel.CutOff = 1E-13 ; % scale ~ sensitivity

% aR_lst = [200, 150, 120, 100, 90, 80, 70, 60, 50];
% D_lst = [360, 180, 120, 90, 60, 36, 18, 9, 6, 3.6, 1.2, 0.6, 0.36];
% D_lst = [36, 10, 3.6, 1, 0.36, 0.1];

% TI_lst = [0, 2, 4, 6, 8, 10, 12];
% TI_lst = [0, 4, 8, 12, 16, 20, 24, 28, 32, 36, 40, 44];%, 48, 52];
% CO_lst = [1, 0.1, 0.01, 0.003, 0.001, 0];
% CO_lst = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 0];
% CO_lst = [1, 15, 0];
% D_lst = [0.36, 3.6, 36]; 
% D_lst = [0.036, 0.1, 0.36, 1.0, 3.6, 10, 36]; 
% BC_lst = ["Twist-periodic", "periodic", "reflective"];
% sigIND_lst = [0, 2, 4, 6, 8, 10];
% sig_lst = [0.2, 0.1, 0.05, 0.02, 0.01, 0.005];
% sig_lst = [0.1, 0.03, 0.01, 0.003, 0.001, 0.0003, 0.0001, 0.00003, 0.00001, 0];
time_lst = [0, 0, 0, 0, 0.003, 0.003, 0.003, 0.003, 0.0003, 0.0003, 0.0003, 0.0003, 0.00003, 0.00003, 0.00003, 0.00003;
            0, 0.00003, 0.0003, 0.003, 0, 0.00003, 0.0003, 0.003, 0, 0.00003, 0.0003, 0.003, 0, 0.00003, 0.0003, 0.003];
% tau_lst = [1, 2, 4, 8, 10, 20];
toc
%% run simulation
disp('Start running simulation...')
parfor cont = 1:1
    results = modelSim_squ_3C1Dftpal(model, time_lst(1,cont), time_lst(2,cont), paramsModel, paramsSys, 1, 0, 0, 0);
end
% results = modelSim_squ_2C1Dftpal(model, paramsModel, paramsSys, 1, 1, 0, 0);

