%%%%%%%% Turing_191221_squ.m %%%%%%%%
% Edit from 191219_squ in 191219—2C1D_GeneralModel
% Full parameter model
% put a_A0 and a_R0 in the F(A,R) function

% Model definition file
% Simulates model for N gridpoints, using a vector of N*numSpecies
%       E.g., for species A, R, and TD (numSpecies  == 3), and N == 3
%             y = [h1, p1, c1, r1, q1, h2, p2, c2, r2, q2, h3, p3, c3, r3, q3], where h1 =
%             concentration of h at cell 1, h2 = concentration of h at cell 2, etc
% Input arguments: 
%       t:                  time (scalar)
%       y:                  vector containing species concentrations
%       outType:            the type of output you want to be returned
%                           'mainModel':        the model itself, to be run after pre-equilibration
%                           'preModel':         pre-equilibration model.  SPATIALLY HOMOGENEOUS
%                           'perception':       function that calculates perception at each gridpoint
%                           'speciesSS':        vector containing indices of species to be tested for steady-stateness in mainModel
%                           'preSpeciesSs':     vector containing indices of species to be tested for steady-stateness in preModel
%                           'preModelIC':       initial conditions for preModel
%                           'jacobianSparsity': OPTIONAL. returns sparsity pattern of Jacobian for
%                                               mainModel.  If you don't want to type it out, set
%                                               to empty vector ([])
%       paramsModel:        structure containing model parameters
%       paramsSys:          structure containing parameters needed to describe model execution
%
% Output arguments:
%       output:             depends on "outType"


function output = Turing_squ_3C1Dftpal(t, y, outType, paramsModel, paramsSys)  

    numSpecies = paramsSys.numSpecies; % number of species in model
    
    %put params into separate variables, for clarity

%     N = paramsSys.N; % number of gridpoints
%     L = paramsSys.L;
%     W = paramsSys.W;
%     a_A = paramsModel.a_A;
%     a_R = paramsModel.a_R;
%     
%     g_A = paramsModel.g_A; 
%     g_R = paramsModel.g_R; 
%     
%     K_A = paramsModel.K_A;
%     K_R = paramsModel.K_R;
%     
%     K = paramsModel.K;    
%     D = paramsModel.D;
%     H = paramsModel.H;
    
    N = paramsSys.N; % number of gridpoints
    L = paramsSys.L;
    W = paramsSys.W;

    a_A = paramsModel.a_A;
    a_M = paramsModel.a_M;
    a_R = paramsModel.a_R;
    
%     a_A0 = paramsModel.a_A0;
%     a_R0 = paramsModel.a_R0;
%     a_M0 = paramsModel.a_M0;
    

    r_A = paramsModel.r_A; 
    r_R = paramsModel.r_R;
    r_M = paramsModel.r_M;
        
    D = paramsModel.D;
    
    K1 = paramsModel.K1;
    K2 = paramsModel.K2;
%     kap = paramsModel.kap;
    
    H1 = paramsModel.H1;
    H2 = paramsModel.H2;

    switch outType 
        case 'mainModel' %full model
            output = zeros(numSpecies*N, 1);            

            %break out y into molecular species (they are interleaved)
            A = y(1 : numSpecies : end - 2);
            R = y(2 : numSpecies : end - 1);
            M = y(3 : numSpecies : end - 0);


            %equations for non-diffusible A and R
            dAdt =  a_A * (A.^H1 + 1)./(A.^H1 + R.^H1 + K1.^H1 + 1) - r_A * A;% + 0.1 * rdcell; 
            dRdt =  a_R * (M.^H2 + 1)./(M.^H2 + K2.^H2 + 1) - r_R * R;% + 0.1 * rdcell;
            dMdt =  a_M * (A.^H1 + 1)./(A.^H1 + R.^H1 + K1.^H1 + 1) - r_M * M;% + 1 * rdcell;
            
            
%             if paramsModel.CutOff ~= 0
%                 scale = 10^(-paramsModel.CutOff); % scale ~ sensitivity
%                 Ir = sparse(diag(M));
%                 TrsfrM = sparse(paramsSys.Trans * Ir - Ir * paramsSys.Trans);
% %                 TrsfrM(TrsfrM ~= 0) = TrsfrM(TrsfrM ~= 0) - 1./(TrsfrM(TrsfrM ~= 0)./paramsModel.CutOff  + 1./TrsfrM(TrsfrM ~= 0));
%                 TrsfrM(TrsfrM ~= 0) = TrsfrM(TrsfrM ~= 0) - 1./(TrsfrM(TrsfrM ~= 0)./scale  + 1./TrsfrM(TrsfrM ~= 0));
%                 dMdt = dMdt + D * sum(TrsfrM, 2);
%             else
%                 dMdt_Df = (D * M' * paramsSys.Q)';
%                 dMdt = dMdt + dMdt_Df; 
%             end


            dMdt_Df = (M' * paramsSys.Q)';
            dMdt_Df((dMdt_Df ~= 0) &(abs(dMdt_Df)< paramsModel.CutOff)) = 0;
            dMdt = dMdt + D * dMdt_Df;  

            %construct output dydt from dh and dp
            output(1 : numSpecies : end - 2) = dAdt;
            output(2 : numSpecies : end - 1) = dRdt;
            output(3 : numSpecies : end - 0) = dMdt;
 
  
            
        case 'preModel' %pre-equilibration model
            %break out y into molecular species (they are interleaved)
             % the fixed concentration of Hh to use for pre-equilibration
            A = y(1);
            R = y(2);
            M = y(3);

%             dAdt = a_A * ((A/K_A).^H + (1/K).^H)./((A/K_A).^H + (R/K_R).^H + 1 + (1/K).^H) - g_A * A;
%             dRdt = a_R * ((A/K_A).^H + (1/K).^H)./((A/K_A).^H + (R/K_R).^H + 1 + (1/K).^H) - g_R * R;
            dAdt = a_A * (A^H1 + 1)/(A^H1 + R^H1 + K1^H1 + 1) - r_A * A;
            dRdt = a_R * (M^H2 + 1)/(M^H2 + K2^H2 + 1) - r_R * R;
            dMdt = a_M * (A^H1 + 1)/(A^H1 + R^H1 + K1^H1 +1) - r_M * M;
            %output
            output = [dAdt; dRdt; dMdt];
                 
        case 'jacobianSparsity' % sparsity pattern of model Jacobian

            output = paramsSys.S;

 
        case 'speciesSs' % indices of species to be tested for steady-stateness in main model
            % everything EXCEPT integrated signal q
%             q = 5 : numSpecies : numSpecies*N;   
            temp = 1 : numSpecies*N;
            output = temp; %look at everything except q
            
        case 'preSpeciesSs' % indices of species to be tested for steady-stateness in preModel
            %  [A, R] 
            output = [1, 2, 3];
            
        case 'preModelIC' %specified initial conditions for preModel
            A0 = a_A/r_A;%a_p / c_p;
            R0 = a_R/r_R;
            M0 = a_M/r_M;
            
%             output = [A0, R0, M0];
            tspan = [0 10000];
            y0 = [A0 R0 M0];
            [t, y] = ode15s(@(t, y)preSol(t, y, paramsModel), tspan, y0, paramsModel);
            output = [y(end,1), y(end,2), y(end,3)];
    end
end
function dydt = preSol(t, y, paramsModel)
    a_A = paramsModel.a_A;
    a_R = paramsModel.a_R;
    a_M = paramsModel.a_M;
    
    r_A = paramsModel.r_A; 
    r_R = paramsModel.r_R; 
    r_M = paramsModel.r_M;
    
    K1 = paramsModel.K1;
    K2 = paramsModel.K2;
      
    H1 = paramsModel.H1;
    H2 = paramsModel.H2;
    
    dydt = [a_A * (y(1)^H1 + 1)/(y(1)^H1 + y(2)^H1 + 1 + K1.^H1) - r_A * y(1); ...
        a_R * (y(3)^H2 + 1)/(y(3)^H2 + K2^H2 + 1) - r_R * y(2); ...
        a_M * (y(1)^H1 + 1)/(y(1)^H1 + y(2)^H1 + 1 + K1.^H1) - r_M * y(3);];
end
