%% DispersionCurve (0720)

function results = SSA_SMRD(paramsSys, para)
    w = paramsSys.w;

    a_A = para(1);
    a_R = para(2);

    g_A = para(3); 
    g_R = para(4);

    K_A = para(5);
    K_R = para(6);
    K = para(7);
    H = para(8);
    Da = para(9);
    Dr = para(10);

    %%
    tspan = [0 10000];
    y0 = 0.1;
    [t, y] = ode45(@(t, y) a_A * ((y./K_A).^H + (1/K).^H)./((y./K_A).^H + ((g_A * a_R * y./(g_R * a_A))./K_R).^H + 1 + (1/K).^H) - g_A * y, tspan, y0);
    As = y(end);
    Rs =  g_A * a_R * As/(g_R * a_A);
%     dAdt = a_A * ((As/K_A).^H + (1/K).^H)./((As/K_A).^H + (Rs/K_R).^H + 1 + (1/K).^H) - g_A * As;
%     dRdt = a_R * ((As/K_A).^H + (1/K).^H)./((As/K_A).^H + (Rs/K_R).^H + 1 + (1/K).^H) - g_R * Rs;

    denom2 = ((As/K_A)^H + (Rs/K_R)^H + 1 + (1/K)^H)^2;
    dFdA = H*(As/K_A)^(H-1)*((Rs/K_R)^H + 1)/K_A/denom2;
    dFdR = -H*(Rs/K_R)^(H-1)*((As/K_A)^H + (1/K)^H)/K_R/denom2;

    J = [dFdA * a_A - g_A, dFdR * a_A; dFdA * a_R, dFdR * a_R - g_R];
%     eig(J);


    % SMRD Discrete lattice
    B = [0, 0; 0, Dr];
    kmax = w/2;
    k = 0:kmax;
    qk = -4*sin(k*pi/(w)).^2;

    dispCuv = zeros(kmax+1,1);
    for i = 1:kmax+1
        dispCuv(i) = max(real(eig(J + qk(i)* B)));
    end
    if dispCuv(1) < 0
        nod_smrd = 1;
    else
        nod_smrd = 0;
    end
    if max(dispCuv) > 0
        dif_smrd = 1;
    else
        dif_smrd = 0;
    end
    if (nod_smrd > 0) & (dif_smrd > 0)
        SSA_smrd = 1;
    else
        SSA_smrd = 0;
    end
    
    % Turing Discrete lattice
    B = [Da, 0; 0, Dr];
    kmax = w/2;
    k = 0:kmax;
    qk = -4*sin(k*pi/(w)).^2;

    dispCuv = zeros(kmax+1,1);
    for i = 1:kmax+1
        dispCuv(i) = max(real(eig(J + qk(i)* B)));
    end
    if dispCuv(1) < 0
        nod_ctrd = 1;
    else
        nod_ctrd = 0;
    end
    if max(dispCuv) > 0
        dif_ctrd = 1;
    else
        dif_ctrd = 0;
    end
    if (nod_ctrd > 0) & (dif_ctrd > 0)
        SSA_ctrd = 1;
    else
        SSA_ctrd = 0;
    end
    
    results = [nod_smrd, dif_smrd, SSA_smrd, nod_ctrd, dif_ctrd, SSA_ctrd];
end
