%% Simulation for data in 6E (211026)
% Simulation platform for the SMRD paper 2C1D(growth-coupled) + LA + with noise

function [t,y] = noiseGenerator_squ(paramsSys, mu0, sig, eta, y0)
    
    % Generate temparal (transit) and spatial (heterogeneious)noise for 
    % the lattice nodes of a particular parameter.
    % this makes N Ornstein-Uhlenbeck processes with mu, sig, and tau as
    % parameters.  Total length (of time) is Tmax
    % if you specify y0 it should be a row containing the initial values which
    % will otherwise just be 0.
    % this program is based on the gillespie paper which gives the very simple
    % updating formula.
    % tau = 10 (half-life of mRNA)
    % step = 0.1; (resilution ok)
    tau = 10;
    step = 0.1;
    t = 0:step:paramsSys.tSpanMax*paramsSys.resetCycle; 
    T = length(t);
    L = paramsSys.Lt;
    W = paramsSys.W;
    N = paramsSys.Nt;
    y = zeros(N, T);
    filename = sprintf('DyNoisMat_tSM%d_mu%.2f_sig%.8f_eta%.8f_%dx%d.mat',paramsSys.tSpanMax,mu0,sig,eta,2*L,2*W);
    if nargin >= 5
        sh0 = y0;
    else
        sh0 = randn(N,1);
    end
    mu = mu0 + eta * sh0;
    y(:,1) = mu;
    
    u = exp(-step/tau);
    sigX = sig * sqrt(1-u^2);

    ind = 1;
    while ind < T 
        ind = ind+1;
        y(:,ind) = y(:,ind-1) * u + mu * (1 - u) + sigX * randn(N ,1);
    end    
    save(filename, 't','y')
end
